#ifndef VGASYS_FON_H
#define VGASYS_FON_H
extern const unsigned char vgasys_fon[6512];
#endif

